@@ -50,7 +50,7 @@ def quad2int(ip):
 class AutoRole(BasePlugin):
     """ Multi-plugin for assigning auto roles from IP. """
 
-    meta_type = 'AutoRole'
+    meta_type = 'Auto Role Plugin'
     security = ClassSecurityInfo()
 
     _properties = (
@@ -59,8 +59,6 @@ class AutoRole(BasePlugin):
              mode='w'),
     )
 
-    manage_options = BasePlugin.manage_options[:1]
-
     def __init__(self, id, title=None, ip_roles=()):
         self._setId(id)
         self.title = title
@@ -71,30 +69,15 @@ class AutoRole(BasePlugin):
             request = getattr(self, 'REQUEST', None)
         if request is None:
             return None
-        
-        ip = request.getClientAddr()
-        
-        # Workaround Zope X-Forwarded-For bug (Collector #2321)
-        # Skip trusted proxies
-        from ZPublisher.HTTPRequest import trusted_proxies
-        if ip in trusted_proxies:
-            ips = request.get('HTTP_X_FORWARDED_FOR')
-            ips = [entry.strip() for entry in ips.split(',')]
-            ips.reverse() # Prefer right-most ip address
-            for ip in ips:
-                if not ip in getattr(request,"trusted_proxies",[]):
-                    return ip
-            else:
-                return None
-        
-        return ip
+        return request.getClientAddr()
     
     def _compile_subnets(self):
-        self._v_compiled = compiled = []
+        self._compiled = compiled = []
         for line in self.ip_roles:
             try:
                 subnet, roles = line.split(':')
-                roles = set([r.strip() for r in roles.split(',')])
+                roles = [r.strip() for r in roles.split(',')]
+                roles = set(filter(None, roles))
             except (ValueError, AttributeError):
                 continue
             try:
@@ -115,7 +98,7 @@ class AutoRole(BasePlugin):
         BasePlugin._setPropValue(self, id, value)
         if id == 'ip_roles':
             self._compile_subnets()
-            if value and len(self._v_compiled) != len(self.ip_roles):
+            if value and len(self._compiled) != len(self.ip_roles):
                 raise ValueError(
                     'ip_roles contains invalid subnets and/or roles!')
 
@@ -125,9 +108,9 @@ class AutoRole(BasePlugin):
     security.declarePrivate('getRolesForPrincipal')
     def getRolesForPrincipal(self, principal, request=None):
         """ Assign roles based on 'request'. """
-        if not getattr(self, '_v_compiled', None):
+        if not getattr(self, '_compiled', None):
             self._compile_subnets()
-        if not self._v_compiled:
+        if not self._compiled:
             return []
         
         ip = quad2int(self._find_ip(request))
@@ -135,7 +118,7 @@ class AutoRole(BasePlugin):
             return []
 
         result = set()
-        for subnet, mask, roles in self._v_compiled:
+        for subnet, mask, roles in self._compiled:
             if ip & mask == subnet:
                 result.update(roles)
         return list(result)
@@ -161,9 +144,9 @@ class AutoRole(BasePlugin):
         if getattr(request, '_auth', None):
             return {}
         
-        if not getattr(self, '_v_compiled', None):
+        if not getattr(self, '_compiled', None):
             self._compile_subnets()
-        if not self._v_compiled:
+        if not self._compiled:
             return {}
 
         # get client IP
@@ -171,7 +154,7 @@ class AutoRole(BasePlugin):
         if not ip:
             return {}
 
-        for subnet, mask, roles in self._v_compiled:
+        for subnet, mask, roles in self._compiled:
             if ip & mask == subnet:
                 return dict(AutoRole=True)
 
